function TouchMenu(x, y, options, rtl)
{
    this.x = x;
    this.y = y;
    this.options = options;
    this.rtl = rtl;
    
    this.show = function()
    {
        console.log("TOUCH MENU.show");
        Blockly.WidgetDiv.show(Blockly.ContextMenu, this.rtl, null);
        if (!this.options.length) 
        {
            Blockly.ContextMenu.hide();
            return;
        }
        /* Here's what one option object looks like:
            {text: 'Make It So',
            enabled: true,
            callback: Blockly.MakeItSo}
        */
        
        var menu = $('<div class="menu"></div>');
        var menuItemCount = 0;
        
        for(var x = 0; x < options.length; ++x) 
        {
            var option = options[x];
            if(option.enabled)
            {
                var menuItem = null;
                
                if(option.text === Blockly.Msg.DELETE_BLOCK ||
                   option.text.replace(/(\d+)/, "%1") === Blockly.Msg.DELETE_X_BLOCKS)
                {
                    menuItem = $('<div class="rotater"><div class="btn btn-icon"> <i class="fa fa-trash"></i> </div></div>');
                }
                else if(option.text === Blockly.Msg.HELP)
                {
        		    menuItem = $('<div class="rotater"><div class="btn btn-icon"> <i class="fa fa-question-circle"></i> </div></div>');
                }
                else if(option.text === Blockly.Msg.DUPLICATE_BLOCK)
                {
        		    menuItem = $('<div class="rotater"><div class="btn btn-icon"> <i class="fa fa-files-o"></i> </div></div>');
                }
                else if(option.text === Blockly.Msg.COLLAPSE_ALL ||
                        option.text === Blockly.Msg.COLLAPSE_BLOCK)
                {
            		menuItem = $('<div class="rotater"><div class="btn btn-icon"> <i class="fa fa-compress"></i> </div></div>');
                }
                else if(option.text === Blockly.Msg.EXPAND_ALL ||
                        option.text === Blockly.Msg.EXPAND_BLOCK)
                {
            		menuItem = $('<div class="rotater"><div class="btn btn-icon"> <i class="fa fa-expand"></i> </div></div>');
                }
                else if(option.text === 'PASTE')
                {
                    menuItem = $('<div class="rotater"><div class="btn btn-icon"> <i class="fa fa-clipboard"></i> </div></div>');
                }
                
                if(menuItem != null)
                {
                    menuItem.find(".btn").data("callback", option.callback);
                    menu.append(menuItem);
                    ++menuItemCount;
                }
            }
        }
            
        // Handle clicks on individual buttons
        menu.on('click', '.btn', function() {
            var callback = $(this).data("callback");
            Blockly.doCommand(callback);
        });
        
        // Handle clicks anywhere on the control
        menu.on('click', function() {
            Blockly.ContextMenu.hide();
        });
        
        // Record windowSize and scrollOffset before adding menu.
        var windowSize = goog.dom.getViewportSize();
        var scrollOffset = goog.style.getViewportPageOffset(document);
        
        var div = Blockly.WidgetDiv.DIV;
        $(div).append(menu);
        
        var menuSize = this.calculateMenuSize(menu, menuItemCount);
    
        // Position the menu.
        var posx = this.x + scrollOffset.x;
        var posy = this.y + scrollOffset.y;
        var position = "top";
        
        // Show the menu buttons below if off the top of the screen
        if(this.y - menuSize.height < 0) 
        {
            position = "bottom";
        }
        
        if(this.x - (menuSize.width/2) < 0)
        {
            posx += ((menuSize.width/2) - this.x);
        }
        else if(this.x + (menuSize.width/2) > windowSize.width)
        {
            posx -= (this.x + (menuSize.width/2)) - windowSize.width;
        }
        
        this.displayMenu(menu, menuItemCount, position);
        menu.toggleClass("active"); 

        Blockly.WidgetDiv.position(posx, posy, windowSize, scrollOffset, this.rtl);
        Blockly.ContextMenu.currentBlock = null;  // May be set by Blockly.Block.
        
        // Set the size of the WidgetDiv to 0, the centre of the menu will be 
        // centered around posx, posy.
        div.style.width="0px";
        div.style.height="0px"
    }
    
    this.calculateMenuSize = function(menu, menuItemCount)
    {
        // Take a clone of the menu, temporarily add it to the WidgetDIV
        // so we can calculate the size
        var menuClone = menu.clone();
        
        var div = Blockly.WidgetDiv.DIV;
        $(div).append(menuClone);
        
        this.displayMenu(menuClone, menuItemCount, "top");
        
        // Remove transform transition durations (so it is instant)
        menuClone.find(".btn").each(function() {
                $(this).css("transition", "");
            });
        
        menuClone.toggleClass("active");
        
        var rect = menuClone.get(0).getBoundingClientRect();
        
        var left = rect.left;
        var right = rect.right;
        var top = rect.top;
        var bottom = rect.bottom;
        
        menuClone.find(".btn").each(function() {
				var rect = $(this).get(0).getBoundingClientRect();
				if(rect.left < left)
				{
				    left = rect.left;
				}
				
				if(rect.right > right)
				{
				    right = rect.right;
				}
				
				if(rect.top < top)
				{
				    top = rect.top;
				}
				
				if(rect.bottom > bottom)
				{
				    bottom = rect.bottom;
				}
			});
			
		menuClone.toggleClass("active");
		menuClone.remove();
			
		return {
            width: right - left,
            height: bottom - top
        };
    }
    
    this.displayMenu = function(menu, menuItemCount, position)
	{
	    var sweepAngle = 0;
	    var incAngle = 0;
	    
	    if(menuItemCount > 1)
	    {
	        sweepAngle = menuItemCount * 22.5;
	        incAngle = sweepAngle / (menuItemCount - 1);
	    }
	    
	    // 90 degrees is 12 o'clock
	    var startAngle = 90 - (sweepAngle / 2);

		if(position == "top")
		{
			startAngle = startAngle;
		}
		else if(position == "bottom")
		{
			startAngle = -startAngle;
			incAngle *= -1;
		}
		else if(position == "left")
		{
			startAngle = 90 - startAngle;
			incAngle *= -1;
		}
		else if(position == "right")
		{
			startAngle = 90 + startAngle;
		}

		var angle = startAngle;
		menu.children().each(function() {
				$(this).css({ 'transform': 'rotate(' + angle + 'deg)'});
				var negAngle = -angle;
				$(this).children().css({ 'transform': 'translateX(-7em) rotate(' + negAngle + 'deg)'});
				angle += incAngle;
			});
	}
}