// Helper function for dealing with empty parameters when generating code
function _option(value)
{
  if(value != null && typeof value == "string" && value != "")
  {
    return ", " + value;
  }

  return "";
}

//// App Blocks

Blockly.JavaScript['app_onstart'] = function(block) {
  var statements_name = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function OnStart()\n{\n" + statements_name + "}\n";
  return code;
};

Blockly.JavaScript['app_showpopup'] = function(block) {
  var message = Blockly.JavaScript.valueToCode(block, 'message', Blockly.JavaScript.ORDER_ATOMIC);
  var code = 'app.ShowPopup(' + message + ');\n';
  return code;
};

Blockly.JavaScript['app_setorientation'] = function(block) {
  var orient = block.getFieldValue('orient');
  var code = 'app.SetOrientation( "' + orient + '" );\n';
  return code;
};

Blockly.JavaScript['app_playsound'] = function(block) {
  var file = Blockly.JavaScript.valueToCode(block, 'file', Blockly.JavaScript.ORDER_ATOMIC);
  var code = 'app.PlaySound(' + file + ');\n';
  return code;
};

Blockly.JavaScript['app_texttospeech'] = function(block) {
  var text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC) || "";
  var pitch = Blockly.JavaScript.valueToCode(block, 'pitch', Blockly.JavaScript.ORDER_ATOMIC) || 1.0;
  var speed = Blockly.JavaScript.valueToCode(block, 'speed', Blockly.JavaScript.ORDER_ATOMIC) || 1.0;
  var code = 'app.TextToSpeech( ' + text + ', ' + pitch + ', ' + speed + ' );\n';
  return code;
};

Blockly.JavaScript['app_explode'] = function(block) {
  var code = 'app.Explode();\n';
  return code;
};

//// Layout Blocks

Blockly.JavaScript['app_createlayout'] = function(block) {
  var type = block.getFieldValue('type');
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateLayout( \"" + type + "\"" +  _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['app_addlayout'] = function(block) {
  var variable_lay = Blockly.JavaScript.valueToCode(block, 'lay', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.AddLayout( " + variable_lay + " );\n";
  return code;
};

Blockly.JavaScript['lay_type'] = function(block) {
  var dropdown_type = block.getFieldValue('type');
  var code = "\""+dropdown_type+"\"";
  return [code, Blockly.JavaScript.ORDER_NONE];
};

Blockly.JavaScript['lay_flow'] = function(block) {
  var flow = Blockly.JavaScript.valueToCode(block, 'flow', Blockly.JavaScript.ORDER_ADDITION);
  var dropdown_flow = block.getFieldValue('flow');
  var code = "\""+dropdown_flow+"\"" + (flow ? " + "+flow : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['lay_layout'] = function(block) {
  var layout = Blockly.JavaScript.valueToCode(block, 'layout', Blockly.JavaScript.ORDER_ADDITION);
  var dropdown_layout = block.getFieldValue('layout');
  var code = "\""+dropdown_layout+"\"" + (layout ? " + "+layout : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['lay_align'] = function(block) {
  var align = Blockly.JavaScript.valueToCode(block, 'align', Blockly.JavaScript.ORDER_ADDITION);
  var dropdown_align = block.getFieldValue('align');
  var code = "\""+dropdown_align+"\"" + (align ? " + "+align : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['lay_touchthrough'] = function(block) {
  var touchthrough = Blockly.JavaScript.valueToCode(block, 'touchthrough', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "\"TouchThrough\"" + (touchthrough ? " + "+touchthrough : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['lay_childaction'] = function(block) {
  var action = block.getFieldValue('lay_action');
  var variable_control = Blockly.JavaScript.valueToCode(block, 'control', Blockly.JavaScript.ORDER_ATOMIC);
  var variable_lay = Blockly.JavaScript.valueToCode(block, 'lay', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "";

  // Insert any set event handler code for the control, e.g. btn.SetOnTouch( btn_OnTouch )
  if(action == "AddChild")
  {
    code += getControlEvents(variable_control, this.workspace);
  }

  code += variable_lay + "." + action + "( " + variable_control + " );\n";
  return code;
};

Blockly.JavaScript['lay_settouchable'] = function(block) {
  var checkbox_touchable = block.getFieldValue('touchable') == 'TRUE';
  var variable_lay = Blockly.JavaScript.variableDB_.getName(block.getFieldValue('lay'), Blockly.Variables.NAME_TYPE);
  var code = variable_lay + ".SetTouchable( " + checkbox_touchable + " );\n";
  return code;
};

//// Image Blocks

Blockly.JavaScript['app_createimage'] = function(block) {
  var file = Blockly.JavaScript.valueToCode(block, 'file', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC) || -1;
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC) || -1;
  var code = "app.CreateImage( " + file + ", " + width + ", " + height + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['img_rotate'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'img', Blockly.JavaScript.ORDER_ATOMIC);
  var angle = Blockly.JavaScript.valueToCode(block, 'angle', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var centerx = Blockly.JavaScript.valueToCode(block, 'centerx', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var centery = Blockly.JavaScript.valueToCode(block, 'centery', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = variable_name + ".Rotate( " + angle + ", " + centerx + ", " + centery +" );\n";
  return code;
};

Blockly.JavaScript['img_scale'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'img', Blockly.JavaScript.ORDER_ATOMIC);
  var scalex = Blockly.JavaScript.valueToCode(block, 'scalex', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var scaley = Blockly.JavaScript.valueToCode(block, 'scaley', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = variable_name + ".Scale( " + scalex + ", " + scaley +" );\n";
  return code;
};

Blockly.JavaScript['img_move'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'img', Blockly.JavaScript.ORDER_ATOMIC);
  var movex = Blockly.JavaScript.valueToCode(block, 'movex', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var movey = Blockly.JavaScript.valueToCode(block, 'movey', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = variable_name + ".Move( " + movex + ", " + movey +" );\n";
  return code;
};

Blockly.JavaScript['img_spin'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'img', Blockly.JavaScript.ORDER_ATOMIC);
  var time = Blockly.JavaScript.valueToCode(block, 'time', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = "Spin( " + variable_name + ", " + time + " );\n";
  return code;
};

Blockly.JavaScript['img_ontouchdownevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( ev )\n{\n  touchX = ev.X; touchY = ev.Y;\n" + statements_statements + "}\n";
  return code;
}

Blockly.JavaScript['img_ontouchupevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( ev )\n{\n  touchX = ev.X; touchY = ev.Y;\n" + statements_statements + "}\n";
  return code;
}

Blockly.JavaScript['img_ontouchmoveevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( ev )\n{\n  touchX = ev.X; touchY = ev.Y;\n" + statements_statements + "}\n";
  return code;
}

//// Text Blocks

Blockly.JavaScript['app_createtext'] = function(block) {
  var text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateText( " + text + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['app_createtextedit'] = function(block) {
  var text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateTextEdit( " + text + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['txt_align'] = function(block) {
  var align = Blockly.JavaScript.valueToCode(block, 'align', Blockly.JavaScript.ORDER_ADDITION);
  var dropdown_align = block.getFieldValue('align');
  var code = "\""+dropdown_align+"\"" + (align ? " + "+align : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['txt_multiline'] = function(block) {
  var multiline = Blockly.JavaScript.valueToCode(block, 'multiline', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "\"Multiline\"" + (multiline ? " + "+multiline : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['txt_settextsize'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'txt', Blockly.JavaScript.ORDER_ATOMIC);
  var size = Blockly.JavaScript.valueToCode(block, 'size', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".SetTextSize( " + size + " );\n";
  return code;
};

Blockly.JavaScript['txt_settextcolor'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'txt', Blockly.JavaScript.ORDER_ATOMIC);
  var col = Blockly.JavaScript.valueToCode(block, 'col', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".SetTextColor( " + col + " );\n";
  return code;
};

Blockly.JavaScript['edit_gettext'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'edit', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".GetText()";
  return [code, Blockly.JavaScript.ORDER_ATOMIC];
};

//// Button Blocks

Blockly.JavaScript['app_createbutton'] = function(block) {
  var text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateButton( " + text + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['btn_style'] = function(block) {
  var style = Blockly.JavaScript.valueToCode(block, 'style', Blockly.JavaScript.ORDER_ADDITION);
  var dropdown_style = block.getFieldValue('style');
  var code = "\""+dropdown_style+"\"" + (style ? " + "+style : "" );
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['btn_ontouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "()\n{\n" + statements_statements + "}\n";
  return code;
}

//// Toggle Button Blocks

Blockly.JavaScript['app_createtoggle'] = function(block) {
  var text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateToggle( " + text + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['tgl_ontouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( isChecked )\n{\n" + statements_statements + "}\n";
  return code;
}

//// Check Box Blocks

Blockly.JavaScript['app_createcheckbox'] = function(block) {
  var text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateCheckBox( " + text + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['chk_ontouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( isChecked )\n{\n" + statements_statements + "}\n";
  return code;
}

//// Spinner Blocks

Blockly.JavaScript['app_createspinner'] = function(block) {
  var list = Blockly.JavaScript.valueToCode(block, 'list', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateSpinner( " + list + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['spn_ontouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( item )\n{\n" + statements_statements + "}\n";
  return code;
}

//// List Blocks

Blockly.JavaScript['app_createlist'] = function(block) {
  var list = Blockly.JavaScript.valueToCode(block, 'list', Blockly.JavaScript.ORDER_ATOMIC);
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateList( " + list + ", " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['lst_ontouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( title, body, type, index )\n{\n" + statements_statements + "}\n";
  return code;
}

Blockly.JavaScript['lst_onlongtouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( title, body, type, index )\n{\n" + statements_statements + "}\n";
  return code;
}

//// Camera Blocks

Blockly.JavaScript['app_createcamera'] = function(block) {
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateCameraView( " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['cam_startpreview'] = function(block) {
  var cam = Blockly.JavaScript.valueToCode(block, 'cam', Blockly.JavaScript.ORDER_ATOMIC);

  var code = "//Start preview after 1 second.\n";
  code += "setTimeout( \"" + cam + ".StartPreview()\", 1000);\n"

  return code;
};

//// Seekbar Blocks

Blockly.JavaScript['app_createseekbar'] = function(block) {
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateSeekBar( " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['skb_ontouchevent'] = function(block) {
  var statements_statements = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function " + block.getProcedureName() + "( value )\n{\n" + statements_statements + "}\n";
  return code;
}

//// Control Blocks

Blockly.JavaScript['control_setmargins'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'control', Blockly.JavaScript.ORDER_ATOMIC);
  var left = Blockly.JavaScript.valueToCode(block, 'left', Blockly.JavaScript.ORDER_ATOMIC);
  var top = Blockly.JavaScript.valueToCode(block, 'top', Blockly.JavaScript.ORDER_ATOMIC);
  var right = Blockly.JavaScript.valueToCode(block, 'right', Blockly.JavaScript.ORDER_ATOMIC);
  var bottom = Blockly.JavaScript.valueToCode(block, 'bottom', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".SetMargins( " + left + ", " + top + ", " + right + ", " + bottom + " );\n";
  return code;
};

//// Math Blocks

Blockly.JavaScript['math_atan2'] = function(block) {
  var y = Blockly.JavaScript.valueToCode(block, 'y', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var x = Blockly.JavaScript.valueToCode(block, 'x', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = "Math.atan2( " + y + ", " + x + " ) / Math.PI * 180";
  return [code, Blockly.JavaScript.ORDER_NONE];
};

//// Media Blocks

Blockly.JavaScript['image'] = function(block) {
  var code = Blockly.JavaScript.quote_(block.getFieldValue('file'));
  return [code, Blockly.JavaScript.ORDER_ATOMIC];
};

Blockly.JavaScript['sound'] = function(block) {
  var code = Blockly.JavaScript.quote_(block.getFieldValue('file'));
  return [code, Blockly.JavaScript.ORDER_ATOMIC];
};

//// Timing Event Blocks

Blockly.JavaScript['do_every'] = function(block) {
  var time = Blockly.JavaScript.valueToCode(block, 'time', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var statements_do = Blockly.JavaScript.statementToCode(block, 'do');
  var code = 'setInterval( function() {\n' + statements_do + ' }, ' + time + ' );\n';
  return code;
};

Blockly.JavaScript['do_after'] = function(block) {
  var time = Blockly.JavaScript.valueToCode(block, 'time', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var statements_do = Blockly.JavaScript.statementToCode(block, 'do');
  var code = 'setTimeout( function() {\n' + statements_do + ' }, ' + time + ' );\n';
  return code;
};

//// Misc blocks

Blockly.JavaScript['js_comment'] = function(block) {
  var text_comment = block.getFieldValue('comment');
  return "\n//" + text_comment + "\n";
};

Blockly.JavaScript['js_log'] = function(block) {
  var text_msg = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_ATOMIC);
  return "console.log(" + text_msg + ")\n";
};

Blockly.JavaScript['js_code'] = function(block) {
  var text_code = block.getFieldValue('code');
  return text_code + "\n";
};

Blockly.JavaScript['js_script'] = function(block) {
  var file = block.getFieldValue('file');
  return "app.Script( \"" + file + "\" )\n";
};

//// NXT Blocks

// Blockly.JavaScript['app_createnxt'] = function(block) {
//   var code = "app.CreateNxt()";
//   return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
// };

//function CreateNxt( callback )
//{
//    var nxt = app.CreateNxt();
//    nxt.SetOnConnected( callback );
//    nxt.ShowDevices();
//    return nxt;
//}

// Blockly.JavaScript['app_createnxt'] = function(block) {
//   var callback = Blockly.JavaScript.valueToCode(block, 'callback', Blockly.JavaScript.ORDER_ATOMIC);
//   var code = "CreateNxt( " + callback + " )";
//   return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
// };

Blockly.JavaScript['app_createnxt'] = function(block) {
  var callback = Blockly.JavaScript.valueToCode(block, 'callback', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateNxt()";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['nxt_connect'] = function(block) {
  var nxt = Blockly.JavaScript.valueToCode(block, 'nxt', Blockly.JavaScript.ORDER_ATOMIC);
  var code = nxt + ".ShowDevices();\n";
  return code;
};

Blockly.JavaScript['nxt_beep'] = function(block) {
  var nxt = Blockly.JavaScript.valueToCode(block, 'nxt', Blockly.JavaScript.ORDER_ATOMIC);
  var frequency = Blockly.JavaScript.valueToCode(block, 'frequency', Blockly.JavaScript.ORDER_ATOMIC) || 100;
  var time = Blockly.JavaScript.valueToCode(block, 'time', Blockly.JavaScript.ORDER_ATOMIC) || 2;
  var code = nxt + ".Beep( " + frequency + ", " + time * 1000 + " );\n";
  return code;
};

Blockly.JavaScript['nxt_drive'] = function(block) {
  var nxt = Blockly.JavaScript.valueToCode(block, 'nxt', Blockly.JavaScript.ORDER_ATOMIC);
  var motors = Blockly.JavaScript.valueToCode(block, 'motors', Blockly.JavaScript.ORDER_ATOMIC) || "";
  var power = Blockly.JavaScript.valueToCode(block, 'power', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var rotations = Blockly.JavaScript.valueToCode(block, 'rotations', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = nxt + ".Drive( " + motors + ", " + power + ", " + rotations + " );\n";
  return code;
};

Blockly.JavaScript['nxt_drivecontinuous'] = function(block) {
  var nxt = Blockly.JavaScript.valueToCode(block, 'nxt', Blockly.JavaScript.ORDER_ATOMIC);
  var motors = Blockly.JavaScript.valueToCode(block, 'motors', Blockly.JavaScript.ORDER_ATOMIC) || "";
  var power = Blockly.JavaScript.valueToCode(block, 'power', Blockly.JavaScript.ORDER_ATOMIC) || 0;
  var code = nxt + ".Drive( " + motors + ", " + power + ", 0 );\n";
  return code;
};

Blockly.JavaScript['nxt_stop'] = function(block) {
  var nxt = Blockly.JavaScript.valueToCode(block, 'nxt', Blockly.JavaScript.ORDER_ATOMIC);
  var motors = Blockly.JavaScript.valueToCode(block, 'motors', Blockly.JavaScript.ORDER_ATOMIC) || "";
  var code = nxt + ".Stop( " + motors + " );\n";
  return code;
};

//// GAME BLOCKS

Blockly.JavaScript['app_creategameview'] = function(block) {
  var width = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var height = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = "app.CreateGameView( " + width + ", " + height + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['gam_setfile'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gam', Blockly.JavaScript.ORDER_ATOMIC);
  var file = Blockly.JavaScript.valueToCode(block, 'file', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".SetFile( " + file.replace(".dsj",".dsj.js") + " );\n";
  return code;
};

//// WEBGL BLOCKS

Blockly.JavaScript['gfx_onload'] = function(block) {
  var statements_name = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function OnLoad()\n{\n" + statements_name + "}\n";
  return code;
};

Blockly.JavaScript['gfx_onready'] = function(block) {
  var statements_name = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function OnReady()\n{\n" + statements_name + "}\n";
  return code;
};

Blockly.JavaScript['gfx_onanimate'] = function(block) {
  var statements_name = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function OnAnimate( time, timeDiff )\n{\n" + statements_name + "}\n";
  return code;
};

Blockly.JavaScript['gfx_oncollide'] = function(block) {
  var statements_name = Blockly.JavaScript.statementToCode(block, 'statements');
  var code = "function OnCollide( a, b )\n{ \n" + statements_name + "}\n";
  return code;
};


Blockly.JavaScript['gfx_addphysics'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var file = Blockly.JavaScript.valueToCode(block, 'gravity', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".AddPhysics( " + file + " );\n";
  return code;
};

Blockly.JavaScript['gfx_enclose'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var groupid = Blockly.JavaScript.valueToCode(block, 'groupid', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".Enclose( " + groupid + _option(options) + " );\n";
  return code;
};

Blockly.JavaScript['gfx_createbackground'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var file = Blockly.JavaScript.valueToCode(block, 'file', Blockly.JavaScript.ORDER_ATOMIC);
  var options = Blockly.JavaScript.valueToCode(block, 'options', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".CreateBackground( " + file + _option(options) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['gfx_createsprite'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var file = Blockly.JavaScript.valueToCode(block, 'file', Blockly.JavaScript.ORDER_ATOMIC);
  var group = Blockly.JavaScript.valueToCode(block, 'group', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".CreateSprite( " + file + _option(group) + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['gfx_setphysics'] = function(block) {
  var obj = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var groupid = Blockly.JavaScript.valueToCode(block, 'groupId', Blockly.JavaScript.ORDER_ATOMIC);
  var type = "\""+block.getFieldValue('type')+"\"";
  var density = Blockly.JavaScript.valueToCode(block, 'density', Blockly.JavaScript.ORDER_ATOMIC);
  var bounce= Blockly.JavaScript.valueToCode(block, 'bounce', Blockly.JavaScript.ORDER_ATOMIC);
  var friction = Blockly.JavaScript.valueToCode(block, 'friction', Blockly.JavaScript.ORDER_ATOMIC);
  var code = obj + ".SetPhysics( " + groupid + _option(type) + _option(density) 
		+ _option(bounce) + _option(friction) + " );\n";
  return code;
};

Blockly.JavaScript['gfx_sprite_play'] = function(block) {
  var obj = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var startFrame = Blockly.JavaScript.valueToCode(block, 'startFrame', Blockly.JavaScript.ORDER_ATOMIC);
  var speed = Blockly.JavaScript.valueToCode(block, 'speed', Blockly.JavaScript.ORDER_ATOMIC);
  var loop = Blockly.JavaScript.valueToCode(block, 'loop', Blockly.JavaScript.ORDER_ATOMIC);
  var code = obj + ".Play( " + startFrame + _option(speed) + _option(loop) + " );\n";
  return code;
};

Blockly.JavaScript['gfx_sprite_stop'] = function(block) {
  var obj = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var code = obj + ".Stop();\n";
  return code;
};

Blockly.JavaScript['gfx_getprop'] = function(block) {
  var obj = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var property = block.getFieldValue('property');
  var code = obj + "." + property + " ";
  return [code, Blockly.JavaScript.ORDER_ADDITION];
};

Blockly.JavaScript['gfx_setprop'] = function(block) {
  var obj = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var property = block.getFieldValue('property');
  var value = Blockly.JavaScript.valueToCode(block, 'value', Blockly.JavaScript.ORDER_ATOMIC);
  var code = obj + "." + property + " = " + value + ";\n";
  return code;
};

Blockly.JavaScript['gfx_createsound'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var file = Blockly.JavaScript.valueToCode(block, 'file', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".CreateSound( " + file + " )";
  return [code, Blockly.JavaScript.ORDER_FUNCTION_CALL];
};

Blockly.JavaScript['gfx_playsound'] = function(block) {
  var obj = Blockly.JavaScript.valueToCode(block, 'snd', Blockly.JavaScript.ORDER_ATOMIC);
  var loop = Blockly.JavaScript.valueToCode(block, 'loop', Blockly.JavaScript.ORDER_ATOMIC);
  var delay = Blockly.JavaScript.valueToCode(block, 'delay', Blockly.JavaScript.ORDER_ATOMIC);
  var gap = Blockly.JavaScript.valueToCode(block, 'gap', Blockly.JavaScript.ORDER_ATOMIC);
  var code = obj + ".Play( " + loop + _option(delay) + _option(gap) + " );\n";
  return code;
};

Blockly.JavaScript['gfx_addbackground'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var sprite = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".AddBackground( " + sprite + " );\n";
  return code;
};

Blockly.JavaScript['gfx_addsprite'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var sprite = Blockly.JavaScript.valueToCode(block, 'sprite', Blockly.JavaScript.ORDER_ATOMIC);
  var x = Blockly.JavaScript.valueToCode(block, 'x', Blockly.JavaScript.ORDER_ATOMIC);
  var y = Blockly.JavaScript.valueToCode(block, 'y', Blockly.JavaScript.ORDER_ATOMIC);
  var w = Blockly.JavaScript.valueToCode(block, 'width', Blockly.JavaScript.ORDER_ATOMIC);
  var h = Blockly.JavaScript.valueToCode(block, 'height', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".AddSprite( " + sprite+", "+x+","+y+_option(w)+_option(h) + " );\n";
  return code;
};


Blockly.JavaScript['gfx_play'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".Play();\n";
  return code;
};

Blockly.JavaScript['gfx_pause'] = function(block) {
  var variable_name = Blockly.JavaScript.valueToCode(block, 'gfx', Blockly.JavaScript.ORDER_ATOMIC);
  var code = variable_name + ".Pause();\n";
  return code;
};


//// OTHER

// Get the code for any event callbacks related to the given control,
// e.g. btn.SetOnTouch( btn_OnTouch ); img.SetOnTouchMove( img_OnTouchMove ); etc
function getControlEvents(control, workspace)
{
  var code = "";

  var blocks = workspace.getAllBlocks();

  for(var i = 0; i < blocks.length; i++) 
  {
    if(blocks[i].type == "btn_ontouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "tgl_ontouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "chk_ontouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "spn_ontouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "lst_ontouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "lst_onlongtouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnLongTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "img_ontouchdownevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouchDown( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "img_ontouchmoveevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouchMove( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "img_ontouchupevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouchUp( " + blocks[i].getProcedureName() + " );\n";
      }
    }
    else if(blocks[i].type == "skb_ontouchevent")
    {
      if(blocks[i].getControl() == control)
      {
        code += control + ".SetOnTouch( " + blocks[i].getProcedureName() + " );\n";
      }
    }
  }

  return code;
}